@@ -25,7 +25,8 @@ class LocationDataSizeView(View):
         try:
             access_token = put_data['IDT']
         except KeyError:
-            logger.error('No "IDT" in: %r', put_data)
+            # https://gitlab.com/Nulide/findmydeviceserver/-/issues/11
+            logger.warning('No "IDT" in: %r', put_data)
             return HttpResponseBadRequest()
 
         # XXX: Don't know what we should do with the index here ;)
