@@ -18,6 +18,9 @@ assert __Path(BASE_PATH, 'findmydevice_project').is_dir()
 ###############################################################################
 # Find My Device settings
 FMD_ACCESS_TOKEN_TIMEOUT_SEC = 5 * 60
+
+# Don't store a new location from Device, if we have one, in this time range:
+FMD_MIN_LOCATION_DATE_RANGE_SEC = 30
 ###############################################################################
 
 
